callDetectStream property

  1. @override
Stream<bool> get callDetectStream

Returns a broadcast stream of events that signal changes in call status.

Stream<bool> that emits true when an active call (incoming or outgoing) is detected, and false when the call ends or no call is active.

Note: This getter returns the same stream as singletonCallDetectStream, but unlike singletonCallDetectStream, callDetectStream will emit the lastCallStatus immediately during use StreamBuilder a widget tree rebuild, ensuring UI stays in sync. singletonCallDetectStream does not re-emit the last value on rebuild.

Implementation

@override
Stream<bool> get callDetectStream => _singletonCallDetector.callDetectStream;