lastCallStatus property

  1. @override
bool get lastCallStatus

Returns the most recent known call status.

  • true - means the last known status was "active call",
  • false - means "no active call".

Provides instant access to the latest emitted value from the stream without needing to listen to it.

Implementation

@override
bool get lastCallStatus => _singletonCallDetector.lastCallStatus;