singletonCallDetectStream property

Stream<bool> get singletonCallDetectStream

Returns a broadcast stream of events that signal changes in call status.

Stream<bool> that emits true when an active call (incoming or outgoing) is detected, and false when the call ends or no call is active.

Note: This is the same underlying stream as callDetectStream, but singletonCallDetectStream does not emit the lastCallStatus on widget tree rebuild during use StreamBuilder. Use if that behavior is needed.

Implementation

Stream<bool> get singletonCallDetectStream => _singletonStream;