call_detector_plugin library
Classes
- CallDetector
- CallDetector is a singleton class designed for detecting and monitoring phone call status on the platform.
Mixins
- CallDetectorMixin
- CallDetectorMixin provides a convenient way to enable call detection functionality in any class without needing to directly instantiate or manage a CallDetector instance.