getCurrentCallStatus method
Asynchronously fetches the current call status from the platform.
Queries the native platform and returns true
if a call is currently active, otherwise false.
Useful for getting an immediate snapshot, as opposed to listening
for stream updates.
Implementation
@override
Future<bool> getCurrentCallStatus() async => _lastCallStatus = await channelService.getCurrentCallStatus();